function x=adtg(p,t,s)
% function x=adtg(p,t,s)
%
% adiabatic temperature gradient deg c/1000 dbar
% ref: bryden,h.,1973,deep-sea res.,20,401-408
% check value:adtg=3.255976e-1 deg c/1000 dbar
% for t=40 deg c, s=40 nsu, p=10000 dbars
%
% Input
% p	m*n matrix of pressures in db
% t	m*n matrix of insitu temperatures
% s 	m*n matirx of insitu slinities
% Output
% x	m*n matrix of adiabatic temperature gradient
% 
% r. schlitzer  (5/18/89)
% modified for general matrices N.L. Bindoff
% 10/August/1990
[m,n]=size(p);
a1=[-2.1687e-13,+1.8676e-11,-4.6206e-10];
a2=[2.7759e-10,-1.1351e-8];
a3=[-5.4481e-12, 8.733e-10, -6.7795e-8,1.8741e-6];
a4=[-4.2393e-7, +1.8932e-5];
a5=[6.6228e-9, -6.836e-7, +8.5258e-5, +3.5803e-4];
s=s-35*ones(m,n);
x=  ( polyval(a1,t).*(p./10) ...
     + polyval(a2,t).*s+ polyval(a3,t)).*(p./10) ...
     + polyval(a4,t).*s ...
     + polyval(a5,t);

%x=(((-2.1687e-13*t+1.8676e-11).*t-4.6206e-10).*(p/10) ...
%     +((2.7759e-10*t-1.1351e-8).*s+((-5.4481e-12*t ...
%     +8.733e-10).*t-6.7795e-8).*t+1.8741e-6)).*(p/10) ...
%     +(-4.2393e-7*t+1.8932e-5).*s ...
%     +((6.6228e-9*t-6.836e-7).*t+8.5258e-5).*t+3.5803e-4;
%  convert adtg from deg c/bar to deg c/1000 dbar for output
x=x*100;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%