%
% function contoursection(data, ylat, xlon, botd, nstd,v,par)
% 
%  a routine that contours hydrographic data in matlab
%  INPUT
%  data	-m*n matrix of data
%  ylat -1*n vector of latitudes
%  xlon	-1*n vector of longitudes
%  botd	-1*n vector of bottom depths
%  nstd	-m*1 vector of standard depths
%  v	-q*4 matrix of contour intervals
%	element 1 min
%	element 2 max
%	element 3 inc
%	element 4 linetype 1=bold, 2=dashed
%	 (min, max, inc, linetype)
%  par	-1*n
%	element 1 is lauto (o or 1 no labelling or labelling)
%	element 2 is itype (1=longitude, 2=latitude)
%       element 3 is start depth 
%	element 4 is maximum depth
%	element 5 is xlen ie lenght of x axis
%	element 6 is ylen ie the length of the y-axis
%
% title "string"
%
%  lauto-scalar =0 (no labelling) =1 (labelling)
%  itype-scalar =1 longitude plot
%		=2 latitude plot
%  
%  xdep	-1*n vector of depths of bottom casts
%  maxd	-1*n vector diving index to the last standard depth
%
function contoursection(data, ylat, xlon,botd, nstd,v,par)
%
[m,n]=size(data);
%
for i=1:n,
	ii=find(finite(data(:,i)));
	if isempty(ii),

		xdep(i)=nstd(m);
		maxd(i)=m
	else
		maxd(i)=min(ii);
		xdep(i)=nstd(maxd(i));
	end
end
maxd
xdep
%
%
h0=figure('papertype','a4letter')
h1=subplot(1,1,1)
%
if par(2)==1,
  [x_dim,index]=sort(xlon);
  maxd=maxd(index);
  xdep=xdep(index);
  data=data(:,index);
  xstring='Longitude (E)'
  xx=[x_dim(1) x_dim x_dim(length(x_dim))];
  maxd=[maxd(1),maxd,maxd(length(xlon))];
  xdep=[nstd(1),xdep,nstd(1)];
  axis_scale=[min(xlon) max(xlon) par(3) par(4)]
else 
  [x_dim,index]=sort(xlon);
  maxd=maxd(index);
  xdep=xdep(index);
  data=data(:,index);
  x_dim=ylat
  xstring='Latitude (S)'
  xx=[x_dim(1) x_dim x_dim(length(x_dim))];
  maxd=[maxd(1),maxd,maxd(length(xlon))];
  xdep=[nstd(m),xdep,nstd(m)];
  axis_scale=[min(ylat) max(ylat) par(3) par(4)]
end
axis(axis_scale)
orient landscape
%
% Put in the background
%
fill(xx, xdep, [0.5 0.5 0.5])
hold on
%
% Loop over the different contour types
%
[q,m]=size(v)
%
contour_levels=[v(1,1):v(1,3):v(1,2)];
keyboard
for ii=2:q
  contour_levels=[contour_levels, v(ii,1):v(ii,3):v(ii,2)]
end
%
contour_levels
LineWidth=2.0
LineStyle='-k'
%
%
%extcontour(x_dim,nstd,data,contour_levels,'linewidth',LineWidth,LineStyle,'label','fill','dash')
extcontour(x_dim,nstd,data,contour_levels,'linewidth',LineWidth,LineStyle,'label','dash','fill')
%extcontour(x_dim,nstd,data,contour_levels,'linewidth',LineWidth,LineStyle,'label')
axis(axis_scale)

map=[0.95 0.95 0.95;
     1.0 1.0 1.0]
colormap(map)
%
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0,'YDir','reverse')
ylabel('\gamma^n')
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0,'YDir','reverse')
xlabel(xstring);
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0,'YDir','reverse')
axis(axis_scale)
set(h1,'Units','centimeters','Position',[4.755,5.45,20,7])


