function [dh, delta] =dynht2(p,t,s,pref)
% function [dh,delta] =dynht2(p,t,s,pref)
%
% Input arguments:
% p	m*1 vector of pressures in decibars
% t	m*1 vector of temperature, deg celsius (ipts-68)
% s	m*1 vector of salinity psu (ipss-78)
% 
% Output arguments:
% dh	m*1 vector of dynamic height (dynamic m = 10 m**2/s**2)
% delta m*1 vector of specific volume anomaly (dimensionless)
%
% dynamic height [dynamic m = 10 m**2/s**2] referenced to 'pref'
% units:
%       reference press pref     decibars
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinitY        s        psu (ipss-78)
%        delta          spec. vol. anomaly  dimensionless
% r. schlitzer  (5/18/89) modified by c. wunsch 2/2/90
%%(replaced loop by cumsum operation for speed) and
%%returns specific volume anomaly -delta
% modified by N.L. Bindoff
% (i) to work with NaN flags for missing data
% (ii) to give dynht wrt to the bottom or the pref.  Values below 
%      bottom topography or non-existent are all set to NaN in
% this code.
%
m=length(p);
dh=zeros(m,1);
n=max(find(~isnan(t)));
id=find(p==pref);
if length(id)==0, fprintf('dynht: no data at pref= %g\n',pref), end
delta=eos80(p,t,s)-v350p(p);
dp=p(2:n)-p(1:n-1);
mdel=(delta(1:n-1)+delta(2:n))/2;
dh(2:n)=-cumsum(dp.*mdel);  
% minus sign because of direction of
% integration; 0 for surface value
if id > n,
	dh(1:n)=dh(1:n)-dh(n);
else
	dh(1:n)=dh(1:n)-dh(id);
end
dh(n+1:m)=NaN*ones(m-n,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
