%
% function [qt,q]=ekman(taux,tauy, long, lat)
%
% taux	1*n vector of x component wind stress (dynes/cm^2)
% tauy	1*n vector of y component wind stress
% long	1*n vector of longitudes for each taux
% lat	1*n vector of latitudes for each tauy
% 
% qt	1*1 scalar of the total ekman transport along path
%	defined by long, lat.  Positive transports are to the right
%	of the path integration. m^3.s^-1
% q	1*n-1 vector of the tranports at the midpts of each lat, long
%	coordinate. Positive tranports are to the right of the path
%	of integration. m^3.s^-1
%
% routine calculates the path integral of the ekman flux given taux
% and tauy at the end of each path.
%
function [qt,q]= ekman(taux,tauy, long, lat)
rho=1000;
factor=(0.1*1000/rho);
factor2=2*7.293*1e-5;
radcv=pi/180;
n=length(taux);
d=zeros(1,n-1);
alpha=zeros(1,n-1);
for i=1:n-1
	if (long(i) == long(i+1)) & (lat(i) == lat(i+1)),
		d(i)=0.0;
		alpha(i)=NaN;
	else
		[d(i),alpha(i)]=dist(long(i),lat(i), ...
			long(i+1),lat(i+1));
	end
end
[f]=factor2*sin(radcv*(lat(1:n-1)+lat(2:n))/2.0);
%
cosa=cos(radcv*alpha);
sina=sin(radcv*alpha);
taup=0.5*cosa.*(taux(1:n-1)+taux(2:n))+ ...
	0.5*sina.*(tauy(1:n-1)+tauy(2:n));
%
[q]=factor*d.*(taup./f); 	% inwards flows are neg. ie convergence
ii=find(~isnan(q));
[qt]=sum(q(ii));






