function [CSOUT,HOUT]=extcontour(arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8,...
                                 arg9,arg10,arg11,arg12,arg13,arg14,arg15,...
                                 arg16,arg17,arg18,arg19,arg20);
%  EXTCONTOUR extended contouring package.
%        EXTCONTOUR(Z) is a contour plot of matrix Z treating the values in Z
%        as heights above a plane.
%        EXTCONTOUR(X,Y,Z), where X and Y are vectors, specifies the X- and Y-
%        axes used on the plot. X and Y can also be matrices of the same
%        size as Z, in which case they specify a surface in an identical
%        manner as SURFACE.
%        EXTCONTOUR(Z,N) and EXTCONTOUR(X,Y,Z,N) draw N contour lines, 
%        overriding the default automatic value.
%        EXTCONTOUR(Z,V) and EXTCONTOUR(X,Y,Z,V) draw LENGTH(V) contour lines 
%        at the values specified in vector V.
%     
%        Following the numeric arguments can be a number of string arguments:
%        EXTCONTOUR(...,'label',144); labels contours. Label spacing is
%                                     optional, default is 144.
%        EXTCONTOUR(...,'fill'); fills with color between contours
%        EXTCONTOUR(...,'thick',...); thickens zero contour lines
%        EXTCONTOUR(...,'dash',...); dashes negative contours
%        and any number of property/value pairs where the properties are
%        text properties (beginning with 'Font...' or 'Rotation') or line 
%        properties (beginning with 'line...' or 'color'). Color and
%        linetype can also be specified as in the PLOT command.
%        e.g., EXTCONTOUR(...,'fontsize',8,'linewidth',3,'--r');
%
%        If viewing a limited region using AXIS, the following is faster
%        and gives better line label spacing:
%        hold on
%        axis([...])
%        extcontour(...)
%        hold off

% Author: Rich Pawlowicz (IOS)  rich@ios.bc.ca
%         12/12/94
% Modified by Peter McIntosh 10/7/96 (dash/thick options, faster if axis set)

%...Test input X, Y and Z arrays for compatibility (if X and Y are vectors)...

string=['MCINTOSH VERSION']
%pause
if min(size(arg1))==1 & min(size(arg2))==1,
  nx=length(arg1);
  ny=length(arg2);
  [zy,zx]=size(arg3);
  if nx~=zx,
    error(['X is of length ',int2str(nx),' but Z(Y,X) is of size ',...
           int2str(zy),'x',int2str(zx)])
  end
  if ny~=zy,
    error(['Y is of length ',int2str(ny),' but Z(Y,X) is of size ',...
           int2str(zy),'x',int2str(zx)])
  end
end

% Option defaults

do_label=0;
do_fill=0;

% Parse options
numarg_for_call=['arg1'];
linarg_for_call=[];
textarg_for_call=[];

ii=2;
while (ii<=nargin),
 arg=eval(['arg' int2str(ii)]);
 if (isstr(arg)),
   xarg=[arg '       '];
   if (lower(xarg(1:3))=='lab'),
    do_label=1;
    if (ii<nargin),    % Check if label interval set
      if ~isstr(eval(['arg' int2str(ii+1)])),
        ii=ii+1;
        textarg_for_call=[textarg_for_call ',''' arg ''',arg' int2str(ii)];
      end;
    end;
   elseif (lower(xarg(1:3))=='fil'),
    do_fill=1;
   elseif (lower(xarg(1:3))=='lin' | lower(xarg(1:3))=='col'),
     ii=ii+1;
     linarg_for_call=[linarg_for_call ',''' arg ''',arg' int2str(ii) ];
   elseif (lower(xarg(1:3))=='fon' | lower(xarg(1:3))=='rot' ),
     ii=ii+1;
     textarg_for_call=[textarg_for_call ',''' arg ''',arg' int2str(ii)];
   elseif ( length(arg)<=3 ),
     colr=isletter(arg);
     if any(colr),
       linarg_for_call=[linarg_for_call ',''color'',''' arg(colr) '''' ];
     end;
     if any(~colr),
       linarg_for_call=[linarg_for_call ',''linestyle'',''' arg(~colr) '''' ];
     end;
   elseif (lower(xarg(1:3))=='thi'),
      textarg_for_call=[textarg_for_call,',''',arg,''''];
   elseif (lower(xarg(1:3))=='das'),
      textarg_for_call=[textarg_for_call,',''',arg,''''];
   else
     error(['invalid argument ' eval(['arg' int2str(ii)])]);
   end;
 else  % numerical argument
   numarg_for_call = [numarg_for_call ',arg' int2str(ii) ];
 end;
 ii=ii+1;
end;

%...Reduce array size according to axis limits if hold is on...
%   (Also only if X and Y are specified and are vectors)
%   (Also if xlim/ylim not [0,1] as this indicates hold but not axis set)

if ishold & ~isempty(findstr(numarg_for_call,'arg1,arg2,arg3')),
  set(gca,'box','on')
  if min(size(arg1))==1 & min(size(arg2))==1,
    xlim=get(gca,'xlim');
    ylim=get(gca,'ylim');
    if ~(all(xlim==[0,1]) & all(ylim==[0,1])),
      xr=find(arg1>xlim(1) & arg1<xlim(2));
      yr=find(arg2>ylim(1) & arg2<ylim(2));
      if length(xr)>0 & length(yr)>0,
	xrmin=max([1 xr(1)-1]);
	xrmax=min([length(arg1) xr(length(xr))+1]);
	xr=[xrmin xr(:)' xrmax];
        unique = [1, find(diff(xr))+1];
        xr=xr(unique);
	yrmin=max([1 yr(1)-1]);
	yrmax=min([length(arg2) yr(length(yr))+1]);
	yr=[yrmin yr(:)' yrmax];
        unique = [1, find(diff(yr))+1];
        yr=yr(unique);
	arg1=arg1(xr);
	arg2=arg2(yr);
	arg3=arg3(yr,xr);
      end
    end
  end
end

% Do the calls

% Preserve hold state at exit
holdon=ishold;

if (do_label | do_fill ),
 if do_fill,
   eval(['[CS,H]=contourfill(' numarg_for_call ');']);
   hold on;
 end;
 if do_label,
   eval(['CS=contoursurf(' numarg_for_call ');']);
   eval(['H=extclabel(CS' linarg_for_call textarg_for_call ');']);
   hold off;
 end;
else         % The standard option
 eval(['CS=contoursurf(' numarg_for_call ');']);
 k=1;
 eval(['H=plot(CS(1,k+[1:CS(2,k)]),CS(2,k+[1:CS(2,k)])' linarg_for_call ');']);
 k=k+1+CS(2,k); 
 while (k<size(CS,2)),
  eval(['H=[H;line(CS(1,k+[1:CS(2,k)]),CS(2,k+[1:CS(2,k)])' linarg_for_call ')];']);
  k=k+1+CS(2,k);
 end;
end;

if (holdon), hold on; else hold off; end;

if nargout>0,
  CSOUT=CS;
end

if nargout>1,
  HOUT=H;
end

