%
% a function to calculate the geostrophic transport per cast pair
% and the total integrated transport
%
% Input
% gvel	m*n matrix of thermal wind velocities (cm.s^-1)
% distance n*1 vector of distance between station pairs
% dstd	m*1 vector of standard depths (db)
% Output
% gtlayer	m-1*1 column vector of cumulative layer transports
% gtstation	n*1 column of cumulative station transports 
% gtvel		m-1*n matrix of area weighted transports
%
function [gtlayer,gtstation,gtvel]=geotrans(gvel,distance,dstd)
[m,n]=size(gvel);
gtlayer=zeros(m-1,1);
gtstation=zeros(1,n);
area=1000*(dstd(2:m)-dstd(1:m-1))*distance;	%approx m^2
gtvel=0.005*(area.*(gvel(1:m-1,:)+gvel(2:m,:)));% gvel is in cm/s
for i=1:m-1
	 jj=find(~isnan(gtvel(i,:)));
	 gtlayer(i)=sum(gtvel(i,jj));
end
gtlayer=cumsum(gtlayer);
%
%
for j=1:n
	 jj=find(~isnan(gtvel(:,j)));
	 if ~isempty(jj),
		 gtstation(j)=sum(gtvel(jj,j));
	end
end
gtstation=cumsum(gtstation);
