function [gvel,alpha,north,east,distance,delta,n]= geovel2( ...
    lon1,lat1,d1,lon2,lat2,d2,sdep,pref)
% function [gvel,alpha,north,east,distance,delta,n]=geovel2( ...
%   lon1,lat1,d1,lon2,lat2,d2,sdep,pref)
%
% calculates  geostrophic velocities ('gvel') [cm/s] along direction
% 'alpha' and its north- ('north') and east-components ('east')
% at standard-depths 'sdep' relative to pressure='pref' (or deepest
% common standard-depth) for two stations
% at positions (lon1,lat1) and (lon2,lat2) and with measured 
% pressure 'd.(:,1)', in-situ temperature 'd.(:,2)', and salinity 'd.(:,3)'
%.NOTE by C. Wunsch,modified from geovel to return dist,
%% which is pair distance, and delta, which is spec.vol anomaly
%%averaged between the two stations
%  longitude is east-longitude
% or the negative of west-longitude. 'alpha' is the direction of the
% normal on the connecting line between the stations.
%%call to dynht must use a ref. level for which interpolation
%%has produced values i.e. 0.
%
% units:
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinity        s        psu (ipss-78)
%       geostr. vel.    gvel     cm/s (positive = along 'alpha')
%        delta specific volume  dimensionless
%
%     n is index of deepest common depth
% r. schlitzer  (5/18/89); modified from geovel.m by
%%c.wunsch, 5 feb 1990
%%note by c.wunsch: gvel is magnitude. must use alpha
%%to get the right sign convention
f=pi/180;
[distance,alpha]=dist(lon1,lat1,lon2,lat2); latm=f*(lat1+lat2)/2;
if latm<0, alpha=alpha+180; end, alpha=rem(alpha+90,360);
omega=7.27e-5; fac=1/(2*omega*sin(latm)*distance);
%fac
%%for use with fukumori data which is already interpolated
%%to standard depths

[dh1,delta1]=dynht2(d1(:,1),d1(:,2),d1(:,3),d1(1,1)); 
%dynht2 is a mod.vers. of
    %%dynht
[dh2,delta2]=dynht2(d2(:,1),d2(:,2),d2(:,3),d2(1,1));
% NOTE: I have chosen the shallowest depth as the reference (NLB)
gvel=zeros(size(delta2)); %assumes all fields have same length  (depths)

%find maximum common depth with data:
j9=find(~isnan(d1(:,2)));
j8=find(~isnan(d2(:,2)));
n=min([j8(length(j8))',j9(length(j9))']);
%
gvel=fac*(dh2-dh1);
delta=(delta1+delta2)/2;
%
%[gvel,dh2,dh1,d2(:,2),d2(:,3),d1(:,2),d1(:,3)]
%
ii=find(sdep==pref);
if length(ii)==0, ii=n; end,  if ii>n, ii=n; end

gvel=gvel-gvel(ii); 

north=sin(f*alpha)*gvel; east=cos(f*alpha)*gvel; 

%%NB velocities and spec. vol. anom.
%below deepest common depth will be set to
%% NaN. deal with this by knowing
%index of deepest common depth, n
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
