%
%function [gvel,alpha,north,east,distance,delta,n]= ...
%          geovelsect(lon, lat, temp, sal, sdep, pref)
%
% this function calculate the geostrophic transport of a section
% given the temerature and salinity on suites of standard depths.
% The function uses the routine geovel2 obtained from carl wunsch.
%
% Inputs:
% lon	n*1 vector of longitudes(deg). of each cast(assumed to be ordered) 
% lat 	n*1 vector of latitudes(deg). of each cast (assumed to be ordered)
% temp  m*n matrix of temperature. temp(i,j) is ith depth, jth cast
% sal	m*n matrix of salinity     sal(i,j) as above (psu)
% sdep  m*1 vector of standard pressures (dbar)
% pref	scalar of reference pressures (dbar)
%
% Outputs:
% gvel	m*n-1 matrix of geostrophic velocities (cm.s-1)
% alpha n-1 vector of directions (direction from north?)
% north	m*n-1 matrix of north components (cm/s)
% east	m*n-1 matrix of east components (cm/s)
% distance n-1 vector of distances between pair data (km)
% delta	m*n-1 matrix of average specific volume anomalies (dim. less)
% n	n-1 vector of common depth indexes
%
% Author:  N.L. Bindoff 
% Date:  14/December/1990
%
function [gvel,alpha,north,east,distance,delta,n]= ...
         geovelsect(lon, lat, temp, sal, sdep, pref)
%
[m,n]=size(temp);
for i=1:n-1
     d1=[sdep,temp(:,i),sal(:,i)];
     d2=[sdep,temp(:,i+1),sal(:,i+1)];
     [gvel(:,i),alpha(i),north(:,i),east(:,i), ...
		distance(i),delta(:,i),n(i)]= ...
         geovel2(lon(i),lat(i),d1,lon(i+1),lat(i+1),d2,sdep,pref);
end

