%+---------------------------------------------------------------------------------+
%|                                                                                 |
%|                                 MATLAB SCRIPT FILE:                             |
%|                                 ===================                             |
%|                            BATCH PROCESSING OF STD DATA                         |
%|                            ============================                         |
%|                                                                                 |
%|                            Programmer.......:  V. Dirita                        |
%|                            Last Revision....: 7th Dec.92                        |
%|                                                                                 |
%| DESCRIPTION: Batch processing of STD data. Able to restore matrices  with  data |
%|              samples missing (only one sample) per cast by linear interpolation |
%|              of the above and below samples.                                    |
%|              Casts corrupted by more than one missing contiguous sample is thus |
%|              rejected.                                                          |
%|                                                                                 |
%|              Secondly,  the user provides standard depths,  which the  software |
%|              applies interpolation algorithms (linear, quadratic) to  calculate |
%|              temperature, salinity, pH, DO, etc.. at these standard depths from |
%|              measurements.                                                      |
%|                                                                                 |
%|              Thirdly, high resolution data is available to allow more  accurate |
%|              calculation of the above parameters.                               |
%|                                                                                 |          
%| FUNCTIONS..: -MissingData2():    looks for missing data in a given cast (row)   |
%|              -MissingGaps():     looks for non-uniformly spaced depth field data|
%|              -PreInterpolate():  pre-interpolation scheme to remove NaN points  |  
%|              -RowSize():         size of row vector containing valid numbers    |        
%|              -InterpolateLow2(): linear interpolation algorithm                 |
%|              -InterpolateLow31():quadratic intepolation algorithm               |
%|              -Interpolatelow3(): cubic spline interpolation algorithm           |
%|              -InterpolateHigh2():high resolution linear interpolation algorithm |
%|              -InterpolateHigh3():high resolution cubic spline interpolation     |
%|                                                                                 |
%+---------------------------------------------------------------------------------+

%load nstd.38;
%load gordon.mat;
[NPOINTS,NCASTS]=size(DEPTH);
i=100;



for i=100:100:NCASTS,

   TEMP(:,1)=TEMPERATURE(:,i);

   if (MissingData2(TEMP(:,1))==1)
      fprintf('missing data, apply pre-interpolation... \n');
      TEMP(:,1)=preinterpolate2(TEMP(:,1), DEPTH(:,i));
   end


   if ((MissingGaps(DEPTH(:,i),600)==0) & (MissingData2(TEMP(:,1))==0))
      TEMP2=interpolatelow2(TEMP(:,1), DEPTH(:,i), nstd);
      TEMP3=interpolatelow31(TEMP(:,1), DEPTH(:,i), nstd);
      str=sprintf('CAST NUMBER #%g\n',i);
      fprintf(str);

      N1=rowsize(TEMP);
      N2=rowsize(TEMP2);
      N3=rowsize(TEMP3);

      plot(TEMPERATURE(1:N1,i), DEPTH(1:N1,i), TEMP2(1:N2), nstd(1:N2), TEMP3(1:N3), nstd(1:N3))
      title(str)
      grid
      xlabel('Temperature C.')
      ylabel('Depth m.')
      pause;
   else
      fprintf('skipping this cast...\n');
   end
end








