%+---------------------------------------------------------------------------------+
%|                                                                                 |
%|                                 MATLAB SCRIPT FILE:                             |
%|                                 ===================                             |
%|                            BATCH PROCESSING OF STD DATA                         |
%|                            ============================                         |
%|                                                                                 |
%|                            Programmer.......:  V. Dirita                        |
%|                            Last Revision....: 7th Dec.92                        |
%|                                                                                 |
%| FILENAME.......: indiansector.m                                                 |
%|                                                                                 |
%| INPUT FILE.....: indiansector.mat                                               |
%|                                                                                 |
%| OUTPUT FILE....: indiansectornodc.mat                                           |
%|                                                                                 |
%| PROCESSING TYPE: high resolution averaging                                      |          
%|                                                                                 |
%+---------------------------------------------------------------------------------+


load indiansector;
load nstd.38;
[NPOINTS, NCASTS]=size(depth);

goodindex=0;
badindex=0;

for i=1:CASTS,

   %------------------- look for missing data/gaps/preinterpolate  ---------------------

   fprintf('CAST: #%g \n', i);

   fprintf('      -running pre-interpolation on any missing data... \n');
   phosphate(:,i)=preinterpolate(phosphate(:,i),depth(:,i));
   oxygen(:,i)=preinterpolate(oxygen(:,i),depth(:,i));
   silicate(:,i)=preinterpolate(silicate(:,i),depth(:,i));
   nitrate(:,i)=preinterpolate(nitrate(:,i),depth(:,i));
   salinity(:,i)=preinterpolate(salinity(:,i),depth(:,i));
   temperature(:,i)=preinterpolate(temperature(:,i),depth(:,i));
 
   fprintf('      -looking for missing sample points........: ');
   flag_phos1=missingdata2(phosphate(:,i));
   flag_oxyg1=missingdata2(oxygen(:,i));
   flag_sili1=missingdata2(silicate(:,i));
   flag_nitr1=missingdata2(nitrate(:,i));
   flag_dept1=missingdata2(depth(:,i));
   flag_sali1=missingdata2(salinity(:,i));
   flag_temp1=missingdata2(temperature(:,i));
   fprintf(' \n');

   fprintf('      -looking for large gaps between depth samples...: ');
   maxgap=500; 
   flag_dept2=missinggaps(depth(:,i), maxgap);
   fprintf('\n');

   fprintf('      -looking for non-monotonicity in depth ');
   flag_dept3=monotonicity(depth(:,i));
   fprintf('\n');


   %-------------------------- retain only good casts ----------------------------------

   flags=~flag_temp1 & ~flag_sali1 & ~flag_dept1 & ~flag_nitr1 & ~flag_sili2 & ~flag_oxyg1 & ~flag_phos1;
   flags= flags & ~flag_dept2 & ~flag_dept3;

   if (flags==1)
      goodindex=goodindex+1;

      fprintf('      -cast good, interpolating temp, salt, oxyg, phosphate, silicate, nitrate... \n');
      PHOSPHATE(:,goodindex)=interpolatelow2(phosphate(:,i), depth(:,i), nstd);
      OXYGEN(:,goodindex)=interpolatelow2(oxygen(:,i), depth(:,i), nstd);
      SILICATE(:,goodindex)=interpolatelow2(silicate(:,i), depth(:,i), nstd);
      NITRATE(:,goodindex)=interpolatelow2(nitrate(:,i), depth(:,i), nstd);
      SALINITY(:,goodindex)=interpolatelow2(salinity(:,i), depth(:,i), nstd);
      TEMPERATURE(:,goodindex)=interpolatelow2(temperature(:,i), depth(:,i), nstd); 
      str=['CAST NUMBER: %g', i];

      N1=rowsize(TEMPERATURE(:,goodindex));
      N2=rowsize(temperature(:,i));
      fprintf('      -plotting graph:: temperature \n');
      plot(TEMPERATURE(1:N1,goodindex), nstd(1:N1),'r', temperature(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('Temperature C.');
      ylabel('Depth m.');
      grid;
      pause(1);

      N1=rowsize(SILICATE(:,goodindex));
      N2=rowsize(silicate(:,i));
      fprintf('      -plotting graph:: silicate \n');
      plot(SILICATE(1:N1,goodindex), nstd(1:N1),'r', silicate(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('silicate');
      ylabel('Depth m.');
      grid;
      pause(1);

      N1=rowsize(SALINITY(:,goodindex));
      N2=rowsize(salinity(:,i));
      fprintf('      -plotting graph:: salinity \n');
      plot(SALINITY(1:N1,goodindex), nstd(1:N1),'r', salinity(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('salinity');
      ylabel('Depth m.');
      grid;
      pause(1);

      N1=rowsize(PHOSPHATE(:,goodindex));
      N2=rowsize(phosphate(:,i));
      fprintf('      -plotting graph:: phosphate \n');
      plot(PHOSPHATE(1:N1,goodindex), nstd(1:N1),'r', phosphate(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('phosphate');
      ylabel('Depth m.');
      grid;
      pause(1);

      N1=rowsize(OXYGEN(:,goodindex));
      N2=rowsize(oxygen(:,i));
      fprintf('      -plotting graph:: oxygen \n');
      plot(OXYGEN(1:N1,goodindex), nstd(1:N1),'r', oxygen(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('oxygen');
      ylabel('Depth m.');
      grid;
      pause(1);

      N1=rowsize(NITRATE(:,goodindex));
      N2=rowsize(nitrate(:,i));
      fprintf('      -plotting graph:: nitrate \n');
      plot(TEMPERATURE(1:N1,goodindex), nstd(1:N1),'r', nitrate(1:N2,i), depth(1:N2,i), 'g')
      title(str);
      xlabel('nitrate');
      ylabel('Depth m.');
      grid;
      pause(1);
   else
      if (flag_phos1==1) fprintf('       ?Error::missing data in phosphate column   \n'); end
      if (flag_sili1==1) fprintf('       ?Error::missing data in silicate column    \n'); end
      if (flag_nitr1==1) fprintf('       ?Error::missing data in nitrate column     \n'); end 
      if (flag_temp1==1) fprintf('       ?Error::missing data in temperature column \n'); end
      if (flag_sali1==1) fprintf('       ?Error::missing data in salinity column    \n'); end
      if (flag_oxyg1==1) fprintf('       ?Error::missing data in oxygen column      \n'); end
      if (flag_dept1==1) fprintf('       ?Error::missing data in pressure column    \n'); end

      if (flag_dept2==1) fprintf('       ?Error::exceeding maximum gap in depth column  \n'); end
      if (flag_dept3==1) fprintf('       ?Error::non-monotonicity found in depth column \n'); end

      badindex=badindex+1;
      badfiles(badindex)=i;
   end
end


%------------------------ store results to output file indiansectornodc.mat ---------------------

fprintf('\n TOTAL NUMBER OF FILES PROCESSED......: %g', i);
fprintf('\n TOTAL NUMBER OF VALID RECORDS FOUND..: %g', goodindex);
fprintf('\n saving to output file indiansectornodc.mat ');

save indiansectornodc.mat aver bot_depth cruise day inst lat long max_prs month rate stat time year pressure temperature salinity oxygen quality;

fprintf('\n\n Good bye, have a nice day.... \n');
 


