%+------------------------------------------------------------+
%|                                                            | 
%| InterpolateHigh():  Averaging routine for high resolution  | 
%|                     STD data.                              |
%|                                                            |
%| Inputs............: InTemperature[N][M]  input temperature |
%|                     InPressure[N][M]     input pressure    |
%|                     StandardPressure[L]  standard pressure |
%|                                                            |
%| Outputs...........: StandardTemperature[L][M] standard temp|
%|                                                            |
%| Call Format.....:                                          | 
%|                                                            |
%+------------------------------------------------------------+

function StandardTemperature=InterpolateHigh(InTemperature, InPressure, StandardPressure)

[IROWS,ICOLS]=size(InTemperature); 
[SROWS,SCOLS]=size(StandardPressure);
SCOLS=ICOLS;
%
% initialise some variables

StandardTemperature=NaN*ones(SROWS,SCOLS);
interval=10

for c=1:ICOLS,
  c
   ROWS=IROWS;
   ii=find(finite(InTemperature(:,c)));
   ROWS=ii(length(ii));
   for r=1:SROWS,
      ii=find((InPressure(:,c)<=StandardPressure(r)+1.5)& ...
	  (InPressure(:,c)>StandardPressure(r)-1.5)& ...
	  (finite(InTemperature(:,c))));
      if ~isempty(ii),
	Index=ii(1);
	if(ii(1)>interval)
	  Nl=ii(1)-interval;
	else
	  Nl=1;
	end
	if(ii(1)>ROWS-interval)
	  Nu=ROWS;
	else
	  Nu=ii(1)+interval;
	end
	StandardTemperature(r,c)=nanmean(InTemperature(Nl:Nu,c));
      else
	StandardTemperature(r,c)=NaN;
      end
    end
end

