%+----------------------------------------------------------+
%|                                                          | 
%| InterpolateLow3():Quadratic Interpolation routine for STD| 
%|                   data.                                  |
%|                                                          |
%| Inputs..........: InTemperature[N][M]  input temperature |
%|                   InPressure[N][M]     input pressure    |
%|                   StandardPressure[L]  standard pressure |
%|                                                          |
%| Outputs.........: StandardTemperature[L][M] standard temp|
%|                                                          |
%| Call Format.....:                                        | 
%|                                                          |
%+----------------------------------------------------------+

function StandardTemperature=InterpolateLow3(InTemperature, InPressure, StandardPressure)

[IROWS,ICOLS]=size(InTemperature); 
[SROWS,SCOLS]=size(StandardPressure);

for c=1:ICOLS,
   ROWS=1; 
   while(InPressure(ROWS,c) ~= NaN) ROWS=ROWS+1; end 
   
   for r=1:SROWS, 
      StandardTemperature(r,c)=NaN;
      if (StandardPressure(r) < InPressure(ROWS-1,c)) 
         StandardTemperature(r,c)=spline(InPressure(1:ROWS-1,c), InTemperature(1:ROWS-1,c), StandardPressure(r));
      end
   end
end 
