%+------------------------------------------------------------+
%|                                                            | 
%| InterpolateLow31(): Quadratic Interpolation routine for STD| 
%|                     data, strictly increasing sequence data|
%|                     only.                                  |
%|                                                            |
%| Inputs............: InTemperature[N][M]  input temperature |
%|                     InPressure[N][M]     input pressure    |
%|                     StandardPressure[L]  standard pressure |
%|                                                            |
%| Outputs...........: StandardTemperature[L][M] standard temp|
%|                                                            |
%| Call Format.....:                                          | 
%|                                                            |
%+------------------------------------------------------------+

function StandardTemperature=InterpolateLow31(InTemperature, InPressure, StandardPressure)

[IROWS,ICOLS]=size(InTemperature); 
[SROWS,SCOLS]=size(StandardPressure);
SCOLS=ICOLS;

for c=1:SCOLS,
   ROWS=IROWS;
   while(InTemperature(ROWS,c) == NaN), ROWS=ROWS-1; end

   for r=1:SROWS, 
      P=round(StandardPressure(r)*1000);
      StandardTemperature(r,c)=NaN;

      for Index=1:ROWS-2,
         P1=round(InPressure(Index+0,c)*1000);
         P2=round(InPressure(Index+1,c)*1000);
         P3=round(InPressure(Index+2,c)*1000);

         if ((P>=P1) & (P<=P3))
            T1=InTemperature(Index+0,c);
            T2=InTemperature(Index+1,c);
            T3=InTemperature(Index+2,c);
            Den=P3*P3*(P2-P1) - P3*(P2*P2-P1*P1) + (P2*P2*P1-P1*P1*P2);
            a0=(P3*P3*(P2*T1-P1*T2) - P3*(P2*P2*T1-P1*P1*T2) + T3*(P2*P2*P1-P1*P1*P2))/Den; 
            a1=(P3*P3*(T2-T1) - T3*(P2*P2-P1*P1) + (P2*P2*T1-P1*P1*T2))/Den;
            a2=(T3*(P2-P1) - P3*(T2-T1) + (T2*P1-T1*P2))/Den;
            StandardTemperature(r,c)=a2*P*P + a1*P + a0;
         end
      end
   end
end 
