%+----------------------------------------------------------+
%|                                                          | 
%| MissingGaps(): Finds and displays casts (column vectors) | 
%|                containing non-uniformly distributed data |
%|                ie: largely spaced sample points, applies |
%|                primarily to strictly  increasing DEPTH[] |
%|                fields only.                              | 
%|                                                          |
%| Inputs.......: InMatrix[N][M]: input matrix              |
%|                maxgap:         maximum allowable gap     |
%|                                                          |
%| Outputs......: status[M] =1: non uniform data in column  |
%|                          =0: uniform data in column      | 
%|                                                          |
%| Call Format..:                                           | 
%|                                                          |
%+----------------------------------------------------------+

function status=MissingGaps(InMatrix, maxgap)

[ROWS,COLS]=size(InMatrix);

for c=1:COLS,
   status(c)=0;
   ROW=ROWS;

   while (InMatrix(ROW,c)==NaN),
      if (ROW<=1) status(c)=1; break; end 
      ROW=ROW-1; 
   end

   for r=1:ROW-1,
      x1=InMatrix(r+0,c);
      x2=InMatrix(r+1,c);
      if ((x2-x1)>=maxgap)
         status(c)=1;
         break;
      end
   end
end

r=sum(status);
fprintf('%g, ',r);

 
