%+------------------------------------------------------------------------+
%|                                                                        | 
%| PreInterpolate2():Pre-Interpolates  missing (NaN) data between  valid  | 
%|                   contiguous data in a given row vector. Missing data  |
%|                   is identified by the symbol: NaN.   Cannot  resolve  |
%|                   two contiguous NaN points. Uses linear interpolation |
%|                                                                        |
%| Inputs..........: InTemperature[N][M]: corrupted matrix eg:temperature.|
%|                   InPressure[N][M]:    interpolating. matrix eg: press.| 
%|                                                                        |
%| Outputs.........: status[M]:           1=unable to restore             |
%|                                        0=column vector restored        |
%| Call Format.....:                                                      | 
%|                                                                        |
%+------------------------------------------------------------------------+

function OutTemperature=PreInterpolate2(InTemperature, InPressure)

[ROWS,COLS]=size(InTemperature);
OutTemperature=InTemperature;
 
for c=1:COLS,
   ROW=ROWS;

   while(OutTemperature(ROW,c)==NaN),
      if (ROW<=1) break; end 
      ROW=ROW-1; 
   end
   
   for r=1:ROW-2,
      T1=OutTemperature(r+0,c);
      T2=OutTemperature(r+1,c);
      T3=OutTemperature(r+2,c);

      if ((T1~=NaN) & (T2==NaN) & (T3~=NaN))
         P1=InPressure(r+0,c);
         P2=InPressure(r+1,c);
         P3=InPressure(r+2,c);
         if ((P1~=NaN) & (P2~=NaN) & (P3~=NaN))
            T2=(T3-T1)/(P3-P1)*(P2-P1) + T1;
            OutTemperature(r+1,c)=T2;      
         end 
      end
   end

   for r=1:ROW,
      if (OutTemperature(r,c)==NaN)
         break;
      end
   end
end


