From:	Carl Wunsch <carl@POND.MIT.EDU> 22-SEP-1990 01:00
To:	BINDOFF@cmltas.cml.oz.au
Subj:	hydrogrpahic programs

Return-Path: <carl%pond.mit.edu%munnari.oz@mitvma.mit.edu>
Received: from diemen.utas.edu.au by hxo.ml.csiro.au ; 22-SEP-1990 00:59:34.76
Received: by diemen.utas.edu.au
	id AA14281 (5.64+/IDA-1.3.4+UTAS-1.9); Sat, 22 Sep 90 01:00:39 +1000
Message-Id: <9009211500.AA14281@diemen.utas.edu.au>
Received: from MITVMA.MIT.EDU by munnari.oz.au with SMTP (5.61+IDA+MU)
	id AA11543; Sat, 22 Sep 1990 00:59:10 +1000
	(from @mitvma.mit.edu:carl@pond.mit.edu for bindoff@cmltas.cml.oz)
Received: from pond.mit.edu by mitvma.mit.edu (IBM VM SMTP R1.2.1MX) with TCP; Fri, 21 Sep 90 10:58:30 EDT
Received: by pond.mit.edu id AA09087g; Fri, 21 Sep 90 11:02:58 EDT
Date: Fri, 21 Sep 90 11:02:58 EDT
From: Carl Wunsch <carl@POND.MIT.EDU>
To: BINDOFF@cmltas.cml.oz.au
Subject: hydrogrpahic programs

Nathan.. I think this is what you want.. Carl
PS I have some inversion programs, now rather complicated, too.


function x=adtg(p,t,s)
% function x=adtg(p,t,s)
%
% adiabatic temperature gradient deg c/1000 dbar
% ref: bryden,h.,1973,deep-sea res.,20,401-408
% check value:adtg=3.255976e-1 deg c/1000 dbar
% for t=40 deg c, s=40 nsu, p=10000 dbars
% 
%   p    pressure in decibars
% r. schlitzer  (5/18/89)
s=s-35;
x=(((-2.1687e-13*t+1.8676e-11).*t-4.6206e-10).*(p/10) ...
     +((2.7759e-10*t-1.1351e-8).*s+((-5.4481e-12*t ...
     +8.733e-10).*t-6.7795e-8).*t+1.8741e-6)).*(p/10) ...
     +(-4.2393e-7*t+1.8932e-5).*s ...
     +((6.6228e-9*t-6.836e-7).*t+8.5258e-5).*t+3.5803e-4;
%  convert adtg from deg c/bar to deg c/1000 dbar for output
x=x*100;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [d,alpha]=dist(lon1,lat1,lon2,lat2)
% function [d,alpha]=dist(lon1,lat1,lon2,lat2)
%
% distance [km] between points (lon1,lat1) and (lon2,lat2)
% and angle 'alpha' [degrees] of connecting line. longitude is
% east-longitude or the negative of west-longitude.
% spherical approx. (note by cw - this is a significant error)
%        alpha           (2) relative to (1)
% -------------------------------------------------
%          0                  eastward
%         90                  northward
%        180                  westward
%        270                  southward
% -------------------------------------------------
%
% r. schlitzer  (5/18/89)
fac=111.194929; alpha=0; dlon=lon2-lon1; dlat=lat2-lat1;
ddlon=fac*cos(2*pi/360*(lat1+lat2)/2)*dlon; ddlat=fac*dlat;
if ddlon==0 & dlat>0,     alpha=90;
elseif ddlon==0 & dlat<0, alpha=-90;
else,                     alpha=360/(2*pi)*atan(ddlat/ddlon); end
if ddlon<0, alpha=alpha+180; end, if alpha<0, alpha=alpha+360; end
d=sqrt(ddlat^2+ddlon^2); 

%%%%%%%%%%%%%%%%%%%%%%%%
function [dh, delta] =dynht2(p,t,s,pref)
% function [dh,delta] =dynht2(p,t,s,pref)
%
% dynamic height [dynamic m = 10 m**2/s**2] referenced to 'pref'
% units:
%       reference press pref     decibars
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinity        s        psu (ipss-78)
%        delta          spec. vol. anomaly  dimensionless
% r. schlitzer  (5/18/89) modified by c. wunsch 2/2/90
  %%(replaced loop by cumsum operation for speed) and
   %%returns specific volume anomaly -delta
xmiss=-1; n=max(find(t~=xmiss)); id=find(p==pref);
if length(id)==0, fprintf('dynht: no data at pref= %g\n',pref), end
delta=eos80(p,t,s)-v350p(p); dp=p(2:n)-p(1:n-1);
mdel=(delta(1:n-1)+delta(2:n))/2; dh=zeros(p(1:n-1));
 dh=-cumsum(dp.*mdel); dh=[0;dh];   %%minus sign because of direction of
 %%integration; 0 for surface value
  dh=dh-dh(id);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function spvol=eos80(p,t,s)
% function spvol=eos80(p,t,s)
% 
% specific volume of sea-water
% equation of state for seawater proposed by jpots 1980
% references
% millero et al 1980, deep-sea res.,27a,255-264
% jpots ninth report 1978,tenth report 1980
% units:
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinity        s        nsu (ipss-78)
%       spec. vol.      spvol    cm**3/g
% check value: spvol = 9.435561e-1 cm**3/g for s = 40 nsu,
% t = 40 deg c, p = 10000 dbars.
%
% r. schlitzer  (5/18/89)
%%same numbers as eos80.m written by cw
%% slightly different logic
n=length(p); if n<=1, spvol=1; else, spvol=ones(p); end
sig=sigma(p,t,s); spvol=spvol./(1+sig/1000);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [gvel,alpha,north,east,distance,delta,n]= ..
         geovel2(lon1,lat1,d1,lon2,lat2,d2,sdep,pref)
% function [gvel,alpha,north,east,distance,delta,n]= ..
%          geovel2(lon1,lat1,d1,lon2,lat2,d2,sdep,pref)
%
% calculates  geostrophic velocities ('gvel') [cm/s] along direction
% 'alpha' and its north- ('north') and east-components ('east')
% at standard-depths 'sdep' relative to pressure='pref' (or deepest
% common standard-depth) for two stations
% at positions (lon1,lat1) and (lon2,lat2) and with measured 
% pressure 'd.(:,1)', in-situ temperature 'd.(:,2)', and salinity 'd.(:,3)'
%.NOTE by C. Wunsch,modified from geovel to return dist,
%% which is pair distance, and delta, which is spec.vol anomaly
%%averaged between the two stations
%  longitude is east-longitude
% or the negative of west-longitude. 'alpha' is the direction of the
% normal on the connecting line between the stations.
%%call to dynht must use a ref. level for which interpolation
%%has produced values i.e. 0.
%
% units:
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinity        s        psu (ipss-78)
%       geostr. vel.    gvel     cm/s (positive = along 'alpha')
%        delta specific volume  dimensionless
%
%     n is index of deepest common depth
% r. schlitzer  (5/18/89); modified from geovel.m by
%%c.wunsch, 5 feb 1990
%%note by c.wunsch: gvel is magnitude. must use alpha
%%to get the right sign convention
f=pi/180;
[distance,alpha]=dist(lon1,lat1,lon2,lat2); latm=f*(lat1+lat2)/2;
if latm<0, alpha=alpha+180; end, alpha=rem(alpha+90,360);
omega=7.27e-5; fac=1/(2*omega*sin(latm)*distance);
%%for use with fukumori data which is already interpolated
%%to standard depths

[dh1,delta1]=dynht2(d1(:,1),d1(:,2),d1(:,3),0); 
%dynht2 is a mod.vers. of
    %%dynht
[dh2,delta2]=dynht2(d2(:,1),d2(:,2),d2(:,3),0);
gvel=zeros(delta2); %assumes all fields have same length  (depths)

%find maximum common depth with data:
j9=find(d1(:,2)~=0);j8=find(d2(:,2)~=0);
n=min([j8(length(j8))',j9(length(j9))']);
 gvel(1:n,1)=fac*(dh2(1:n)-dh1(1:n));
ii=find(sdep==pref);
delta=(delta1+delta2)/2;
if length(ii)==0, ii=n; end,  if ii>n, ii=n; end

gvel=gvel-gvel(ii); 

n1=length(gvel); if((n1-n)>0),gvel(n+1:n1)=zeros(n1-n,1);
 delta(n+1:n1)=zeros(n1-n,1); end
north=sin(f*alpha)*gvel; east=cos(f*alpha)*gvel; 
%%NB velocities and spec. vol. anom.
%below deepest common depth will be set to
%% zero. deal with this by knowing
%index of deepest common depth, n
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% p = pressure80(dpth,xlat)     p80   p80   p80   p80
% PRESSURE FROM DEPTH FROM SAUNDER'S  FORMULA WITH EOS80
% REFERENCE: SAUNDERS,PETER M., PRACTICAL CONVERSION OF PRESSURE
%            TO DEPTH., J.P.O., APRIL 1981

% R. MILLARD. put into matlab by c.wunsch, 1989
% MARCH 9, 1983
% CHECK VALUE: P80=7500.004 DBARS;FOR LAT=30 DEG., DEPTH=7321.45% METERS
      function  p =pressure80(dpth,xlat)
           PLAT = abs(xlat*pi/180.);
      D=sin(PLAT);
      C1=5.92E-3+D.^2*5.25E-3;
      p=((1.-C1)-sqrt(((1.-C1).^2)-(8.84E-6*dpth)))/4.42E-6;

          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function sig=sigma(p,t,s)
% function sig=sigma(p,t,s)
%
% calculates in situ density.
% millero et al 1980, deep-sea res.,27a,255-264
% jpots ninth report 1978,tenth report 1980
% units:
%       pressure        p        decibars
%       temperature     t        deg celsius (ipts-68)
%       salinity        s        nsu (ipss-78)
%                       sigma    (10.**-3)g/cm**3
%
% r. schlitzer  (5/18/89)

% change pressure from input units of decibars to bars
% square root salinity.
p=p/10;sr=sqrt(abs(s));
% density pure water at atm press in kg/m3 = (10**-3)gm/cm3
r1=((((6.536332e-9*t-1.120083e-6).*t+1.001685e-4).*t ...
     -9.095290e-3).*t+6.793952e-2).*t- .157406;
% seawater density atm press.
r2=(((5.3875e-9*t-8.2467e-7).*t+7.6438e-5).*t-4.0899e-3).*t+0.824493;
r3=(-1.6546e-6*t+1.0227e-4).*t-5.72466e-3; r4=4.8314e-4;
sig=(r4*s + r3.*sr + r2).*s + r1;
% compute compression terms
e=(9.1697e-10*t+2.0816e-8).*t-9.9348e-7;
bw=(5.2787e-8*t-6.12293e-6).*t+8.50935e-5; b=bw+e.*s;
c=(-1.6078e-6*t-1.0981e-5).*t+2.2838e-3;
aw=((-5.77905e-7*t+1.16092e-4).*t+1.43713e-3).*t+3.239908;
a=(1.91075e-4*sr+c).*s+aw;
b1=(-5.3009e-4*t+1.6483e-2).*t+7.944e-2;
a1=((-6.1670e-5*t+1.09987e-2).*t-0.603459).*t+54.6746;
kw=(((-5.155288e-5*t+1.360477e-2).*t-2.327105).*t+148.4206).*t+19652.21;
k0=(b1.*sr+a1).*s+kw;
% evaluate pressure polynomial and return
k=(b.*p+a).*p+k0;
sig=(k.*sig+1000*p)./(k-p);
% sig remains unchanged since is (10**-3)gm/cm**3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function c=sndspd1(p,t,s)
%% c= sndspd1(p,t,s).simple formula
%%taken from Apel, p.349 for approximate
%%speed of sound.needs to be checked for accuracy 
%he says supposedly good to 0.2m/sec. 
%%c. wunsch december 1 1989
c0=1493.0;alpha0=3.0;beta0=-.006;gamma0=-.04;
delta0=1.2; epsilon0=-.01;zeta0=.0164;
c=c0+alpha0*(t-10) +beta0*(t-10).^2+gamma0*(t-18).^2 ..
+delta0*(s-35)+epsilon0*(t-18).*(s-35)+zeta0*abs(p);























P





e


----- End Included Message -----


