function curl=curl_z(x,y,lat,long)
% 
% A function designed to return the vertical component of the
% curl field.  Missing components are assumed to NAN's. Therefore
% derivatives which include NaN's will also be flaged as NAN's with
% a consequent reduction in the number valid points.
% 
% Input
% x	m*n matrix of x component
% y	m*n matrix of y component 
% lat m*n matrix of latitude point
% long	m*n matrix of logitude points
%
% Output
% curl	m-1*n-1 matrix of the vertical component of curl
%
factor=pi/180;					% degree to radians
[m,n]=size(x);
colatitude=-(lat-90*ones(m,n))*factor;
colongitude=long*factor;
%
dellat=2*factor*(lat(2,1)-lat(1,1));
dellong=2*factor*(long(1,2)-long(1,1));
%
iip1=3:m;
iim1=1:m-2;
factor=sin(colatitude);
dxdlat=(factor(2:m-1,2:n-1).*x(iip1,2:n-1)-...
    factor(2:m-1,2:n-1).*x(iim1,2:n-1))/dellat;
%
jjp1=3:n;
jjm1=1:n-2;
dydlon=(y(2:m-1,jjp1)-y(2:m-1,jjm1))/dellong;
%
r=6371*1000;             % mean radius of the earth in metres
curl=(dydlon-dxdlat)./(r*factor(2:m-1,2:n-1));
%keyboard
