%
%   Simple mean of ssh data at crossover points, without any orbit
%   corrections, then goes on to calculate GCE spherical harmonics
%   for each cycle.
%
%   Uses cross_results for input data to ensure same data are used
%   as for global crossover adjustment
%


load cross_ha_hd_124.mat; 

' Data loaded'

%  Take first ncyc cycles

ncyc=124;


%  No of coefficients for soln

degree=6
nconstraints=(degree+1)^2+2;  % extra 2 for 7,0 and 8,0 terms at this stage

%
'  Cut out unnecessary data - xovers where there are less than .6*ncyc pairs'
%

ind=((ha>-9000)&(hd>-9000));
ind=(sum(ind')>.6*ncyc)';


lat_ncyc=lat(~ind);
lon_ncyc=lon(~ind);

lat=lat(ind); 
lon=lon(ind);

ha(~ind,:)=[];
hd(~ind,:)=[];

%
'  Remove pts with raw xover rms > 0.4 m (25 pts in all)'
%

ind=((ha>-9000)&(hd>-9000));
crms=(sum(((ha-hd)'.*ind').^2)./sum(ind'))';
crms=sqrt(crms);
i=(crms<.4);

lat_rms=lat(~i);
lon_rms=lon(~i);

lat=lat(i);
lon=lon(i);

ha(~i,:)=[];
hd(~i,:)=[];

% plot data coverage
% red dot - valid points
% blue + - ncyc exclusion
% green circle - rms crossover > 40 cm
%
plot(lon,lat,'r.',lon_ncyc,lat_ncyc,'b+',lon_rms,lat_rms,'go');
axis([0 360 -90 90]);
hold on; coastlines(2);
print;

ind=((ha>-9000)&(hd>-9000));

%
'   Form mean ssh at each crossover point'
%

h=0.5*(sum(ind'.*(ha+hd)')./sum(ind'));
h=h';

%   
' Form residuals'
%

va=ind.*(ha-h*ones(1,ncyc));
vd=ind.*(hd-h*ones(1,ncyc));


%  
' Convert latitudes to geocentric'
%

rlat=lat*pi/180;
rlon=lon*pi/180;

ef=1/298.257;absq=(1-ef)^2;
rlat=atan(absq*tan(rlat));

nn=size(ha,1);

% to degree 8 zonal harmonics
g1_zonal=[ones(nn,1) sin(rlat) 1/2*(3*sin(rlat).^2-1) 5/2*sin(rlat).^3-3/2*sin(rlat)];
g1_zonal=[g1_zonal 1/8*(35*sin(rlat).^4-30*sin(rlat).^2+3) 63/8*sin(rlat).^5-35/4*sin(rlat).^3+15/8*sin(rlat)];
g1_zonal=[g1_zonal 231/16*sin(rlat).^6-315/16*sin(rlat).^4+105/16*sin(rlat).^2-5/16];
g1_zonal=[g1_zonal 429/16*sin(rlat).^7-693/16*sin(rlat).^5+315/16*sin(rlat).^2-35/16*sin(rlat)];
g1_zonal=[g1_zonal 6435/128*sin(rlat).^8-12012/128*sin(rlat).^6+6930/128*sin(rlat).^4-1260/128*sin(rlat).^2+35/128];

% degree 1 tesseral/sectorial
g1_one=[cos(rlat).*cos(rlon) cos(rlat).*sin(rlon)];

% degree 2 tesseral/sectorial
g1_two=[3*sin(rlat).*cos(rlat).*cos(rlon) 3*sin(rlat).*cos(rlat).*sin(rlon)];
g1_two=[g1_two 3*cos(rlat).^2.*cos(2*rlon)  3*cos(rlat).^2.*sin(2*rlon)];

% degree 3 tesseral/sectorial
g1_three=[cos(rlat).*(15/2*sin(rlat).^2-3/2).*cos(rlon) cos(rlat).*(15/2*sin(rlat).^2-3/2).*sin(rlon)];
g1_three=[g1_three 15*cos(rlat).^2.*sin(rlat).*cos(2*rlon) 15*cos(rlat).^2.*sin(rlat).*sin(2*rlon)];
g1_three=[g1_three 15*cos(rlat).^3.*cos(3*rlon) 15*cos(rlat).^3.*sin(3*rlon)]; 

% degree 4 tesseral/sectorial
g1_four=[5/2*cos(rlat).*(7*sin(rlat).^3-3*sin(rlat)).*cos(rlon) 5/2*cos(rlat).*(7*sin(rlat).^3-3*sin(rlat)).*sin(rlon)];
g1_four=[g1_four 15/2*cos(rlat).^2.*(7*sin(rlat).^2-1).*cos(2*rlon) 15/2*cos(rlat).^2.*(7*sin(rlat).^2-1).*sin(2*rlon)];
g1_four=[g1_four 105*sin(rlat).*cos(rlat).^3.*cos(3*rlon) 105*sin(rlat).*cos(rlat).^3.*sin(3*rlon)];
g1_four=[g1_four 105*cos(rlat).^4.*cos(4*rlon) 105*cos(rlat).^4.*sin(4*rlon)]; 

% degree 5 tesseral/sectorial
g1_five=[cos(rlat).*(315/8*sin(rlat).^4-105/4*sin(rlat).^2+15/8).*cos(rlon)];
g1_five=[ g1_five cos(rlat).*(315/8*sin(rlat).^4-105/4*sin(rlat).^2+15/8).*sin(rlon)];
g1_five=[g1_five cos(rlat).^2.*(315/2*sin(rlat).^3-105/2*sin(rlat)).*cos(2*rlon)];
g1_five=[g1_five cos(rlat).^2.*(315/2*sin(rlat).^3-105/2*sin(rlat)).*sin(2*rlon)];
g1_five=[g1_five 105/2*cos(rlat).^3.*(9*sin(rlat).^2-1).*cos(3*rlon)];
g1_five=[g1_five 105/2*cos(rlat).^3.*(9*sin(rlat).^2-1).*sin(3*rlon)];
g1_five=[g1_five 945*sin(rlat).*cos(rlat).^4.*cos(4*rlon) 945*sin(rlat).*cos(rlat).^4.*sin(4*rlon)];
g1_five=[g1_five 945*cos(rlat).^5.*cos(5*rlon) 945*cos(rlat).^5.*sin(5*rlon)];

% degree 6 tesseral/sectorial
g1_six=[cos(rlat).^6.*(693/8*sin(rlat).^5-315/4*sin(rlat).^3+105/8*sin(rlat)).*cos(rlon)];
g1_six=[g1_six cos(rlat).^6.*(693/8*sin(rlat).^5-315/4*sin(rlat).^3+105/8*sin(rlat)).*sin(rlon)];
g1_six=[g1_six cos(rlat).^2.*(3465/8*sin(rlat).^4-945/4*sin(rlat).^2+105/8).*cos(2*rlon)];
g1_six=[g1_six cos(rlat).^2.*(3465/8*sin(rlat).^4-945/4*sin(rlat).^2+105/8).*sin(2*rlon)];
g1_six=[g1_six cos(rlat).^3.*(3465/2*sin(rlat).^3-945/2*sin(rlat)).*cos(3*rlon)];
g1_six=[g1_six cos(rlat).^3.*(3465/2*sin(rlat).^3-945/2*sin(rlat)).*sin(3*rlon)];
g1_six=[g1_six cos(rlat).^4.*(10395/2*sin(rlat).^2-945/2).*cos(4*rlon)];
g1_six=[g1_six cos(rlat).^4.*(10395/2*sin(rlat).^2-945/2).*sin(4*rlon)];
g1_six=[g1_six cos(rlat).^5.*(10395*sin(rlat)).*cos(5*rlon) cos(rlat).^5.*(10395*sin(rlat)).*sin(5*rlon)];
g1_six=[g1_six 10395*cos(rlat).^6.*cos(6*rlon) 10395*cos(rlat).^6.*sin(6*rlon)];

%
%
g1=[g1_zonal g1_one g1_two g1_three g1_four g1_five g1_six];

%
'  Calculate spherical harmonics '
%  (do this per cycle, to be able to take
%  individual cycle data drop-outs into account

for i=1:ncyc
   g3=(ind(:,i)*ones(1,nconstraints)).*g1(:,1:nconstraints);
%   gs(:,i)=inv(diag(diag((g3'*g3))))*g3'*.5*(va(:,i)+vd(:,i));
   gs(:,i)=inv(g3'*g3)*g3'*.5*(va(:,i)+vd(:,i));
   i
end

% 
'  Start plotting  '
%
% ************ need to fix this bit up to plot zonals then sectorial/tesserals

hold off
plot(1:ncyc,[gs+.05*[1:nconstraints]'*ones(1,ncyc)],'w-');hold on
plot(1:ncyc,.05*[1:nconstraints]'*ones(1,ncyc),'w--')
title('Sph. har. coefficents obtained from simple mean of data')
axis([1,ncyc+1,0,.05*nconstraints+.02])
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
text((ncyc+1.2)*ones(nconstraints,1),.05*[1:nconstraints]',labels)
xlabel('Cycle No.')
ylabel('Coefficient [m]')
orient tall

'pause'
pause

%   Now do the same for orthogonalised coefficients

or(:,1)=g1(:,1);
or(:,2)=g1(:,2)-or(:,1)*(inv(or(:,1)'*or(:,1))*or(:,1)'*g1(:,2));
or(:,3)=g1(:,3)-or(:,1:2)*(inv(or(:,1:2)'*or(:,1:2))*or(:,1:2)'*g1(:,3));
%or(:,10)=g1(:,10)-or(:,1:3)*(inv(or(:,1:3)'*or(:,1:3))*or(:,1:3)'*g1(:,10));
%or(:,4:9)=g1(:,4:9)-or(:,10)*(inv(or(:,10)'*or(:,10))*or(:,10)'*g1(:,4:9));

for i=4:9;
or(:,i)=g1(:,i)-or(:,1:i-1)*(inv(or(:,1:i-1)'*or(:,1:i-1))*or(:,1:i-1)'*g1(:,i));
end;
%or(:,11:16)=g1(:,11:16);
%for i=11:16;
%or(:,i)=or(:,i)-or(:,1:i-1)*(inv(or(:,1:i-1)'*or(:,1:i-1))*or(:,1:i-1)'*g1(:,i));
%end;


for i=1:ncyc
   g3=(ind(:,i)*ones(1,nconstraints)).*or(:,1:nconstraints);
   gs(:,i)=inv(g3'*g3)*g3'*.5*(va(:,i)+vd(:,i));
end

hold off
plot(1:ncyc,[gs+.05*[1:nconstraints]'*ones(1,ncyc)],'w-');hold on
plot(1:ncyc,.05*[1:nconstraints]'*ones(1,ncyc),'w--')
title('Orthogonal coefficents obtained from simple mean of data')
axis([1,ncyc+1,0,.05*nconstraints+.02])
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
text((ncyc+1.2)*ones(nconstraints,1),.05*[1:nconstraints]',labels)
xlabel('Cycle No.')
ylabel('Coefficient [m]')
orient tall

pause

%
%  Now go on to it all again with zonal 'area-weighting' of data
%

%  Obtain 25 zones

zones=min(dlat)-.01+(max(dlat)+.01-min(dlat))*[0:1:25]'/25;

[nzone,zones]=hist(dlat,zones);
wtzone=1./sqrt(nzone);

wt=interp1(zones,wtzone,dlat);

g1wt=kron(wt,ones(1,9)).*g1;


for i=1:ncyc
   g3=(ind(:,i)*ones(1,nconstraints)).*g1wt(:,1:nconstraints);
   gs(:,i)=inv(diag(diag((g3'*g3))))*g3'*(.5*wt.*(va(:,i)+vd(:,i)));
%   gs(:,i)=inv(g3'*g3)*g3'*(.5*wt.*(va(:,i)+vd(:,i)));
end

hold off
plot(1:ncyc,[gs+.05*[1:nconstraints]'*ones(1,ncyc)],'w-');hold on
plot(1:ncyc,.05*[1:nconstraints]'*ones(1,ncyc),'w--')
title('Sph. har. coefficents obtained from zonally weighted simple mean of data')
axis([1,ncyc+1,0,.05*nconstraints+.02])
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
text((ncyc+1.2)*ones(nconstraints,1),.05*[1:nconstraints]',labels)
xlabel('Cycle No.')
ylabel('Coefficient [m]')
orient tall

pause
