%
%
% Load the data for the freshwater flux fields.
% In this case it is the GASP data from Phil Reid
%
% This version of Freshwater fluxes doesnot integrate
% the rainfall, rather it looks at a velocity.
%
load levitusdata
latlev=lat;
lonlev=lon;
%
load freshwater
lon=long'
lat=lat'% so ssh_harmonics runs ok!
%
%
% Now find the point in the levitus data closest to the
% fluxdata
%
mm=80
nn=97
for i=1:mm
  [Y,indexlat(i)]=min(abs(lat(i)*ones(180,1)-latlev));
end
for j=1:nn
  [Y,indexlon(j)]=min(abs(lon(j)*ones(360,1)-lonlev));
end
%
% Now calculate the distribution of beta
%
temp=temp(indexlon,indexlat)';
salt=salt(indexlon,indexlat)';
[m,n]=size(temp)
press=100*ones(m,n);
the=theta(press,temp,salt,0);
betaterm=beta(salt,the,press);
%
mask=zeros(mm,nn);
ii=find(isnan(temp));
mask(ii)=NaN*ones(length(ii),1);
%
av_flux=(PmE1+PmE2+...
    PmE3+PmE4+...
    PmE5+PmE6+...
    PmE7+PmE8+...
    PmE9+PmE10+...
    PmE11+PmE12)/12 + mask;
%
%
PmE1=PmE1-mask-av_flux;
PmE2=PmE2-mask-av_flux;
PmE3=PmE3-mask-av_flux;
PmE4=PmE4-mask-av_flux;
PmE5=PmE5-mask-av_flux;
PmE6=PmE6-mask-av_flux;
PmE7=PmE7-mask-av_flux;
PmE8=PmE8-mask-av_flux;
PmE9=PmE9-mask-av_flux;
PmE10=PmE10-mask-av_flux;
PmE11=PmE11-mask-av_flux;
PmE12=PmE12-mask-av_flux;
%
%
delt=365.25*24*60*60/12		% time interval for integration
h_mix=100
% flux data are mm/year
%factor=-0.001*salt.*betaterm/(12*delt);
factor=0.001/(12*delt);
%
%
% Integrate, assuming that the sea-surface height field is
% initially zero at last day of proceeding year
%
eta1= factor.*PmE1*delt;
eta2= eta1+ factor.*PmE2*delt;
eta3= eta2+ factor.*PmE3*delt;
eta4= eta3+ factor.*PmE4*delt;
eta5= eta4+ factor.*PmE5*delt;
eta6= eta5+ factor.*PmE6*delt;
eta7= eta6+ factor.*PmE7*delt;
eta8= eta7+ factor.*PmE8*delt;
eta9= eta8+ factor.*PmE9*delt;
eta10= eta9+ factor.*PmE10*delt;
eta11= eta10+ factor.*PmE11*delt;
eta12= eta11+ factor.*PmE12*delt;
%
%
av_eta= (eta1+eta2+eta3+eta4+eta5+eta6+eta7+eta8+eta9+eta10+...
		eta11+eta12)/12;
av_eta=av_eta + mask;
%
[m,n]=size(eta1);
mean_eta=zeros(m,12);
for i=1:12
  string=['eta',num2str(i)]
  eval(['mean_eta(:,i)=meanstd2(eta',num2str(i),');']);
end
%
%
mean_PmE=zeros(m,12);
for i=1:12
  eval(['mean_PmE(:,i)=meanstd2(PmE',num2str(i),');']);
end
%
index2=find(finite(PmE1));
factor=cos(lat*pi/180);
factor2=factor(:,ones(1,nn));
for i=1:12
  string=['m_PmE',num2str(i)]
  eval(['m_PmEm2(',num2str(i),')=mean(0.001*factor2(index2).*PmE',num2str(i),'(index2));']);
  eval(['m_PmE(',num2str(i),')=mean(0.001*PmE',num2str(i),'(index2));']);
end
%
%
for i=1:12
  string=['m_eta',num2str(i)]
  eval(['m_eta(',num2str(i),')=mean(eta',num2str(i),'(index2));']);
end
%
%
h0=figure('papertype','a4letter')
h1=subplot(1,1,1)
%orient landscape
time=0:30:359

%plot(time,m_PmE)
%hold on
%plot(time,m_PmEm2,'--')
plot(time,m_eta,'-.')
grid
axis([0 360 -0.02 0.02])
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
ylabel('height (m)')
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
xlabel('Time, days');
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
title('GASP_freshwater')
set(h1,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
print -deps figure_freshwater.eps
%
%
%
mean_beta=meanstd2(betaterm);
mean_salt=mean_eta./(h_mix*mean_beta(:,ones(1,12)));
%
save model_freshwater_fluxes eta1 eta2 eta3 eta4 eta5 eta6 eta7...
    eta8 eta9 eta10 eta11 eta12 lat lon




