%
%
% Load the data for the wind fields.
% In this case it is Hellerman and Rosenstein
%
load depths
mask=zeros(size(depth));
ii=find(depth>=0);
mask(ii)= NaN*ones(1,length(ii));
ii=find(depth<0);
mask(ii)= 0.0*ones(1,length(ii));
%
load hellerman.mat
%
% Note the Hellerman winds are in CGS units
% so need to convert wind stresses to S.I. units
% by multiplying by 0.1
%
[m,n]=size(decx);
curl1=0.1*curl_z(janx,jany,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl2=0.1*curl_z(febx,feby,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl3=0.1*curl_z(marx,mary,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl4=0.1*curl_z(aprx,apry,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl5=0.1*curl_z(mayx,mayy,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl6=0.1*curl_z(junx,juny,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl7=0.1*curl_z(julx,july,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl8=0.1*curl_z(augx,augy,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl9=0.1*curl_z(sepx,sepy,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl10=0.1*curl_z(octx,octy,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl11=0.1*curl_z(novx,novy,lat(:,ones(1,n)),lon(:,ones(m,1))');
curl12=0.1*curl_z(decx,decy,lat(:,ones(1,n)),lon(:,ones(m,1))');
%
av_curl=(curl1+curl2+curl3+curl4+curl5+curl5+curl6+...
    curl7+curl8+curl9+curl10+curl12)/12;
av_curl= av_curl + mask(2:89,2:179); 
%
curl1=curl1-av_curl;
curl2=curl2-av_curl;
curl3=curl3-av_curl;
curl4=curl4-av_curl;
curl5=curl5-av_curl;
curl6=curl6-av_curl;
curl7=curl7-av_curl;
curl8=curl8-av_curl;
curl9=curl9-av_curl;
curl10=curl10-av_curl;
curl11=curl11-av_curl;
curl12=curl12-av_curl;
%
% curl1, curl2, curl3, ... are the wind stress curl field
% for january, february, march, ....
%
lat=lat(2:m-1)
lon=lon(2:n-1)
degrad=pi/180;
c_1=15
rho=1000
g=10
H=3000
H_equiv=1000
H_forcing=800
omega=7.292e-5
factor= -(c_1^2/(rho*g*H_forcing))./(2*omega*...
    sin(degrad*(lat(:,ones(1,n-2)))));
%
% Integrate, assuming that the sea-surface height field is
% initially zero at last day of proceeding year
%
delt=365.25*24*60*60/12		% time interval for integration
eta1= factor.*curl1*delt;
eta2= eta1+ factor.*curl2*delt;
eta3= eta2+ factor.*curl3*delt;
eta4= eta3+ factor.*curl4*delt;
eta5= eta4+ factor.*curl5*delt;
eta6= eta5+ factor.*curl6*delt;
eta7= eta6+ factor.*curl7*delt;
eta8= eta7+ factor.*curl8*delt;
eta9= eta8+ factor.*curl9*delt;
eta10= eta9+ factor.*curl10*delt;
eta11= eta10+ factor.*curl11*delt;
eta12= eta11+ factor.*curl12*delt;
%
%
av_eta= (eta1+eta2+eta3+eta4+eta5+eta6+eta7+eta8+eta9+eta10+...
		eta11+eta12)/12;
%av_eta= av_eta + mask(2:89,2:179); 
av_eta= mask(2:89,2:179); 
%
% now set the sea-surface height field with respect to the average
eta1=eta1-av_eta;
eta2=eta2-av_eta;
eta3=eta3-av_eta;
eta4=eta4-av_eta;
eta5=eta5-av_eta;
eta6=eta6-av_eta;
eta7=eta7-av_eta;
eta8=eta8-av_eta;
eta9=eta9-av_eta;
eta10=eta10-av_eta;
eta11=eta11-av_eta;
eta12=eta12-av_eta;
%
%
mean_eta=zeros(m-2,12);
for i=1:12
  string=['eta',num2str(i)]
  eval(['mean_eta(:,i)=meanstd2(eta',num2str(i),');']);
end
%
%
mean_curl=zeros(m-2,12);
for i=1:12
  eval(['mean_curl(:,i)=meanstd2(curl',num2str(i),'+mask(2:89,2:179));']);
end


