%
%  Trying to produce plots of low-level spherical harmonic
%  representation of seasonal variation of sea-surface
%  height field based on the model of sea-surface mixing.
%
%  Note: I have assumed that model_flues2.m has been run
%        prior to this routine
%  Author: N.L. Bindoff  (based on Herman Van Hysen sst.m
%                         routine)
%
%load results
%load temp2
%
%global lats
%
%
% Latitude and longitude information have to be arranged into a
% column matrix.
%
[M,N]=size(eta1)
tlat=lat(:,ones(1,N));
tlon=lon(:,ones(M,1))';
tlat=reshape(tlat,M*N,1);
tlon=reshape(tlon,M*N,1);
%tlat=kron([60 30 0 -30 -60]',ones(12,1));
%tlon=kron(ones(5,1),30*[0:11]');
%
% for spherical harmonic analysis eliminate the most extreme northern
% and southern latitudes because T/P data donot exist there.
%
indexnorth=find(lat>=60)
indexsouth=find(lat<=-60)
regionnorth=NaN*ones(length(indexnorth),N);
regionsouth=NaN*ones(length(indexsouth),N);
for i=1:36
  i
  eval(['eta',num2str(i),'(indexnorth,:)=regionnorth;'])
  eval(['eta',num2str(i),'(indexsouth,:)=regionsouth;'])
end
%
% The data are arranged, so that lat-lon space corresponds to 
% row and columns correspond time.
%
tdat=zeros(M*N,36);

for k=1:36
  string=['tdat(:,',num2str(k),')=reshape(eta',num2str(k),',M*N,1);']
  eval(string)
end 

%
%tdat=-tdat
%
%  convert lat's, and lon's to radians
%

tlat=tlat*pi/180;
tlon=tlon*pi/180;
nn=length(tlat);
%
% for checking one can use the test data below
% tdat=[0.025*sin(tlat(:,ones(1,36)))];

tg1=[ones(nn,1) sin(tlat) 1/2*(3*sin(tlat).^2-1) cos(tlat).*cos(tlon) cos(tlat).*sin(tlon)];
tg1=[tg1 3*sin(tlat).*cos(tlat).*cos(tlon) 3*sin(tlat).*cos(tlat).*sin(tlon)];
tg1=[tg1 3*cos(tlat).^2.*cos(2*tlon)  3*cos(tlat).^2.*sin(2*tlon)];
 
% Interpolate t to cycles, over the 50 cycles
ncyc=73
tlat=tlat(~isnan(tdat(:,1)));
tlon=tlon(~isnan(tdat(:,1)));
tg1(isnan(tdat(:,1)),:)=[];
tdat(isnan(tdat(:,1)),:)=[];
tdat=[tdat tdat tdat];

[MM,NN]=size(tdat);
NN=NN/3
col=NaN*zeros(ncyc,1);
frac=NaN*zeros(ncyc,1);
day=NaN*zeros(ncyc,1);

for i=1:ncyc
  day(i)=(i-1)*10+266;           % start day 266
  col(i)=fix((day(i)/365)*NN)+1;
  frac(i)=rem(day(i),365/NN)/(365/NN);
  t(:,i)=tdat(:,col(i))+frac(i)*(tdat(:,col(i)+1)-tdat(:,col(i)));
end

%
% Now invert the matrix to get the harmonics
%

tsh=inv(tg1'*tg1)*tg1'*t;
save TSH.mat tsh
%
% Calculate the residual for each cycle
%

R2=zeros(1,ncyc);
for j=1:ncyc
  R2(j)=(tg1*tsh(:,j))'*(tg1*tsh(:,j))/(t(:,j)'*t(:,j));
end



hold off;
plot(1:ncyc,[tsh+0.05*[1:9]'*ones(1,ncyc)],'w-');hold on
plot(1:ncyc,0.05*[1:9]'*ones(1,ncyc),'w--')
title('Harmonic coefficients sea surface height')

axis([1,ncyc+1,0,0.05*9+.02])
labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22']; 
text((ncyc+1.2)*ones(9,1),0.05*[1:9]',labels)
xlabel('Cycle No.')
ylabel('Coefficient [m]')
orient tall
print -dpsc figure1.ps
%
% Figure with dates on bottom axis
%
%*******************************************************
date=([1:ncyc]*10-94)/365.25+1993;date=date';
nconstraints=9
hold off
h0=figure('papertype','a4letter')
plot(date,[tsh+.05*[1:nconstraints]'*ones(1,ncyc)],'w-');
hold on
axis([1992.78,1995.73,0,.05*nconstraints+.02]);
vax=gca;
blanks=(['      ';'      ';'      ';'      ';'      ']);
set(vax,'XTick',[1992.5:1/12:1996])
set(vax,'XTickMode','manual')
set(vax,'Box','on')
set(vax,'XTickLabelMode','manual')
set(vax,'FontSize',10)
set(vax,'XTickLabels',...
['1992.5';blanks;'1993.0';blanks;'1993.5';blanks;'1994.0';blanks;...
'1994.5';blanks;'1995.0';blanks;'1995.5';blanks;'1996.0'])
hold on
plot(date,.05*[1:nconstraints]'*ones(1,ncyc),'w--')
title('Sph. har. coefficents obtained from within-cycle GCE')
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
text((1995.78)*ones(nconstraints,1),.05*[1:nconstraints]',labels)
xlabel('Cycle No.')
ylabel('Coefficient [m]')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
orient tall

%******************************************************

h0=figure('papertype','a4letter')
linewidth=3
h3=subplot(1,1,1)
plot(1:ncyc,R2,'w-')
title('R^2 SSH')
xlabel('Cycle No.')
ylabel('Variance Explained')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
orient portrait
print -dpsc figure2.ps




