%
%  Trying to produce plots of low-level spherical harmonic
%  representation of seasonal variation of sea-surface
%  height field based on the model of sea-surface mixing.
%
%  Note: I have assumed that model_flues2.m has been run
%        prior to this routine
%  Author: N.L. Bindoff  (based on Herman Van Hysen sst.m
%                         routine)
%
%load results
%load temp2
%
%global lats
%
%
% Latitude and longitude information have to be arranged into a
% column matrix.
%
[M,N]=size(eta1)
tlat=lat(:,ones(1,N));
tlon=lon(:,ones(M,1))';
tlat=reshape(tlat,M*N,1);
tlon=reshape(tlon,M*N,1);
%tlat=kron([60 30 0 -30 -60]',ones(12,1));
%tlon=kron(ones(5,1),30*[0:11]');
%
% for spherical harmonic analysis eliminate the most extreme northern
% and southern latitudes because T/P data donot exist there.
%
indexnorth=find(lat>=61)
indexsouth=find(lat<=-61)
regionnorth=NaN*ones(length(indexnorth),N);
regionsouth=NaN*ones(length(indexsouth),N);
case=input('Months or 10 Days, (12, 36)')
for i=1:case
  i
  eval(['eta',num2str(i),'(indexnorth,:)=regionnorth;'])
  eval(['eta',num2str(i),'(indexsouth,:)=regionsouth;'])
end
%
% The data are arranged, so that lat-lon space corresponds to 
% row and columns correspond time.
%
tdat=zeros(M*N,case);
for k=1:case
  string=['tdat(:,',num2str(k),')=reshape(eta',num2str(k),',M*N,1);']
  eval(string)
end 

%tdat=zeros(M*N,12);
%tdat(:,1)=reshape(eta1,M*N,1);      % January
%tdat(:,2)=reshape(eta2,M*N,1);      % February
%tdat(:,3)=reshape(eta3,M*N,1);      % March
%tdat(:,4)=reshape(eta4,M*N,1);
%tdat(:,5)=reshape(eta5,M*N,1);
%tdat(:,6)=reshape(eta6,M*N,1);
%tdat(:,7)=reshape(eta7,M*N,1);
%tdat(:,8)=reshape(eta8,M*N,1);
%tdat(:,9)=reshape(eta9,M*N,1);
%tdat(:,10)=reshape(eta10,M*N,1);
%tdat(:,11)=reshape(eta11,M*N,1);
%tdat(:,12)=reshape(eta12,M*N,1);
%
%tdat=-tdat
%
%  convert lat's, and lon's to radians
%

tlat=tlat*pi/180;
tlon=tlon*pi/180;
nn=length(tlat);
%
% for checking one can use the test data below
% tdat=0.025*[sin(tlat(:,ones(1,12)))];
% There should be (degree+1)^2 coeffs - ie. for degree 3, 16 coeffs.
%
nconstraints=input('NCONSTRAINTS, 9,16')
if nconstraints==16,
tg1=[ones(nn,1) sin(tlat) 1/2*(3*sin(tlat).^2-1) cos(tlat).*cos(tlon) cos(tlat).*sin(tlon)];
tg1=[tg1 3*sin(tlat).*cos(tlat).*cos(tlon) 3*sin(tlat).*cos(tlat).*sin(tlon)];
tg1=[tg1 3*cos(tlat).^2.*cos(2*tlon)  3*cos(tlat).^2.*sin(2*tlon)];
%adding degree 3 spherical harmonics
tg1=[tg1 5/2*sin(tlat).^3-3/2*sin(tlat) cos(tlat).*(15/2*sin(tlat).^2-3/2).*cos(tlon) cos(tlat).*(15/2*sin(tlat).^2-3/2).*sin(tlon) ... 
15*cos(tlat).^2.*sin(tlat).*cos(2*tlon) 15*cos(tlat).^2.*sin(tlat).*sin(2*tlon) 15*cos(tlat).^3.*cos(3*tlon) 15*cos(tlat).^3.*sin(3*tlon)]; 
else
%
tg1=[ones(nn,1) sin(tlat) 1/2*(3*sin(tlat).^2-1) cos(tlat).*cos(tlon) cos(tlat).*sin(tlon)];
tg1=[tg1 3*sin(tlat).*cos(tlat).*cos(tlon) 3*sin(tlat).*cos(tlat).*sin(tlon)];
tg1=[tg1 3*cos(tlat).^2.*cos(2*tlon)  3*cos(tlat).^2.*sin(2*tlon)];
end
% 
% Interpolate t to cycles, over the 50 cycles
%ncyc=73
ncyc=108
ncyc=124
tlat=tlat(~isnan(tdat(:,1)));
tlon=tlon(~isnan(tdat(:,1)));
tg1(isnan(tdat(:,1)),:)=[];
tdat(isnan(tdat(:,1)),:)=[];
%tdat=[tdat tdat tdat];
tdat=[tdat];

[MM,NN]=size(tdat);
%NN=NN/3
NN=NN
col=NaN*zeros(ncyc,1);
frac=NaN*zeros(ncyc,1);
day=NaN*zeros(ncyc,1);
t=zeros(MM,ncyc);

for i=1:ncyc
  i
  day(i)=(i-1)*10+266;           % start day 266
  day(i)
  col(i)=rem(day(i),365);
  col(i)=fix((col(i)/365)*NN)+1;
%  col(i)=fix((day(i)/365)*NN)+1;
  col(i)
  frac(i)=rem(day(i),365/NN)/(365/NN);
  frac(i)
  if col(i)< case,
     t(:,i)=tdat(:,col(i))+frac(i)*(tdat(:,col(i)+1)-tdat(:,col(i)));
  else
     t(:,i)=tdat(:,col(i))+frac(i)*(tdat(:,1)-tdat(:,col(i)));
  end
end

%
% Now invert the matrix to get the harmonics
%

tsh=inv(tg1'*tg1)*tg1'*t;
%
% Calculate the residual for each cycle
%

R2=zeros(1,ncyc);
for j=1:ncyc
  R2(j)=(tg1*tsh(:,j))'*(tg1*tsh(:,j))/(t(:,j)'*t(:,j));
end
%
%
h0=figure('papertype','a4letter')
h3=subplot(1,1,1)
hold off;
plot(1:ncyc,[tsh+0.05*[1:nconstraints]'*ones(1,ncyc)],'w-');hold on
%
%nconstraints=9
load TPSHCOEF
load nathan_124.mat
plot(1:ncyc,[sh+.05*[1:nconstraints]'*ones(1,ncyc)],'w--');
%
plot(1:ncyc,0.05*[1:nconstraints]'*ones(1,ncyc),'w--')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
title('Harmonic coefficients sea surface height')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
%
axis([1,ncyc+1,0,0.05*nconstraints+.02])
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
h4=text((ncyc+1.2)*ones(nconstraints,1),0.05*[1:nconstraints]',labels)
set(h4,'Fontsize',16,'Fontname','Helvetica')
xlabel('Cycle No.')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
ylabel('Coefficient [m]')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
orient tall
print -dpsc figure1.ps
%
%
%
% Figure with dates on bottom axis
%
%*******************************************************
date=([1:ncyc]*10-94)/365.25+1993;date=date';
%nconstraints=9
hold off
h0=figure('papertype','a4letter')
h3=subplot(1,1,1)
plot(date,[tsh+.05*[1:nconstraints]'*ones(1,ncyc)],'w-');
hold on
%
load TPSHCOEF
load nathan_124.mat
plot(date,[sh+.05*[1:nconstraints]'*ones(1,ncyc)],'w--');
%
axis([1992.78,1995.73,0,.05*nconstraints+.02]);
vax=gca;
blanks=(['      ';'      ';'      ';'      ';'      ']);
set(vax,'XTick',[1992.5:1/12:1996])
set(vax,'XTickMode','manual')
set(vax,'Box','on')
set(vax,'XTickLabelMode','manual')
set(vax,'FontSize',10)
set(vax,'XTickLabels',...
['1992.5';blanks;'1993.0';blanks;'1993.5';blanks;'1994.0';blanks;...
'1994.5';blanks;'1995.0';blanks;'1995.5';blanks;'1996.0'])
hold on
plot(date,.05*[1:nconstraints]'*ones(1,ncyc),'w--')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
title('Sph. har. coefficents obtained from within-cycle GCE')
if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
h4=text((1995.78)*ones(nconstraints,1),.05*[1:nconstraints]',labels)
set(h4,'Fontsize',16,'Fontname','Helvetica')
xlabel('Year')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
ylabel('Coefficient [m]')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
orient tall
print -dpsc figure2.ps
%
%******************************************************
%
h0=figure('papertype','a4letter')
linewidth=3
h3=subplot(1,1,1)
plot(1:ncyc,R2,'w-')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
title('R^2 SSH')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
xlabel('Cycle No.')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
ylabel('Variance Explained')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
orient portrait
print -dpsc figure3.ps

%
%
%
TOP=(nansum((sqrt(sh(1:nconstraints,:).*tsh(1:nconstraints,:)).*sqrt(sh(1:nconstraints,:).*tsh(1:nconstraints,:)))'));
BOT=(nansum((sqrt(sh(1:nconstraints,:).*sh(1:nconstraints,:)).*sqrt(tsh(1:nconstraints,:).*tsh(1:nconstraints,:)))'));
R2SH=TOP./BOT
h0=figure('papertype','a4letter')
linewidth=3
h3=subplot(1,1,1)
plot(1:nconstraints,R2SH,'w-')
axis([0 nconstraints -1 1])
grid
%set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
%title('R^2 Model and Data')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
xlabel('Harmonic')
set(h3,'Fontsize',16,'Fontname','Helvetica','LineWidth',2.0)
ylabel('Correlation')
set(h3,'Fontsize',14,'Fontname','Helvetica','LineWidth',2.0)

if(nconstraints==9);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22'];end
if(nconstraints==16);labels=['C00';'C10';'C20';'C11';'S11';'C21';'S21';'C22';'S22';'C30';'C31';'S31';'C32';'S32';'C33';'S33'];end

h4=text(1*[1:nconstraints]',1.05*ones(nconstraints,1),labels)
set(h4,'Fontsize',14,'Fontname','Helvetica')
orient portrait
print -dpsc figure4.ps





