%
%
% Load the data for the freshwater flux fields.
% In this case it is the GASP data from Phil Reid
%
load levitusdata
latlev=lat;
lonlev=lon;
%
load freshwater
lon=long'
lat=lat'% so ssh_harmonics runs ok!
%
%
% Now find the point in the levitus data closest to the
% fluxdata
%
mm=80
nn=97
for i=1:mm
  [Y,indexlat(i)]=min(abs(lat(i)*ones(180,1)-latlev));
end
for j=1:nn
  [Y,indexlon(j)]=min(abs(lon(j)*ones(360,1)-lonlev));
end
%
% Now calculate the distribution of beta
%
temp=temp(indexlon,indexlat)';
salt=salt(indexlon,indexlat)';
[m,n]=size(temp)
press=100*ones(m,n);
the=theta(press,temp,salt,0);
betaterm=beta(salt,the,press);
%
mask=zeros(mm,nn);
ii=find(isnan(temp));
mask(ii)=NaN*ones(length(ii),1);
%
av_flux=(PmE1+PmE2+...
    PmE3+PmE4+...
    PmE5+PmE6+...
    PmE7+PmE8+...
    PmE9+PmE10+...
    PmE11+PmE12)/12 + mask;
%
%
PmE1=PmE1-mask-av_flux;
PmE2=PmE2-mask-av_flux;
PmE3=PmE3-mask-av_flux;
PmE4=PmE4-mask-av_flux;
PmE5=PmE5-mask-av_flux;
PmE6=PmE6-mask-av_flux;
PmE7=PmE7-mask-av_flux;
PmE8=PmE8-mask-av_flux;
PmE9=PmE9-mask-av_flux;
PmE10=PmE10-mask-av_flux;
PmE11=PmE11-mask-av_flux;
PmE12=PmE12-mask-av_flux;
%
%
delt=365.25*24*60*60/12		% time interval for integration
h_mix=100
% flux data are mm/year
%factor=0.001*h_mix*(betaterm.*salt/h_mix)/(12*delt);
convvel=0.001/(12*delt);         % m per second
%
%
% Integrate, assuming that the sea-surface height field is
% initially zero at last day of proceeding year
%
%lat=lat(2:m-1)
%lon=lon(2:n-1)
degrad=pi/180;
%
rho=1000
g=10
H=3000
c_1=g*H
omega=7.292e-5
f=(2*omega*sin(degrad*(lat(:,ones(1,n)))));
beta=(2*omega*cos(degrad*(lat(:,ones(1,n)))))/(6371*1000);
deg2m=2*111*1000*cos(degrad*(lat(:,ones(1,n))));
k=2*pi/(90*111*1000)
factor= -f.*f.*deg2m./(g*H*beta);
%
eta1= factor.*PmE1*convvel;
eta2= factor.*PmE2*convvel;
eta3= factor.*PmE3*convvel;
eta4= factor.*PmE4*convvel;
eta5= factor.*PmE5*convvel;
eta6= factor.*PmE6*convvel;
eta7= factor.*PmE7*convvel;
eta8= factor.*PmE8*convvel;
eta9= factor.*PmE9*convvel;
eta10= factor.*PmE10*convvel;
eta11= factor.*PmE11*convvel;
eta12= factor.*PmE12*convvel;
%
%
av_eta= (eta1+eta2+eta3+eta4+eta5+eta6+eta7+eta8+eta9+eta10+...
		eta11+eta12)/12;
av_eta=av_eta + mask;
%
%
% integrate across each basin
%
alpha=1.0e-8
for k=1:12
  k
  for i=1:80
    flag=length(find(isnan(eta1(i,:))));
    [i,lat(i),flag]
    if flag==0,
      eval(['[eta',num2str(k),'(i,:),A]=sverdrup_fric(eta',num2str(k),'(i,:)*beta(i,1)/deg2m(i,1),deg2m(i,1),alpha,beta(i,1));'])
    else
      eval(['eta',num2str(k),'(i,:)=integrate(eta',num2str(k),'(i,:));'])
    end
  end
end
%
%
[m,n]=size(eta1);
mean_eta=zeros(m,12);
for i=1:12
  string=['eta',num2str(i)]
  eval(['mean_eta(:,i)=meanstd2(eta',num2str(i),');']);
end
%
%
mean_PmE=zeros(m,12);
for i=1:12
  eval(['mean_PmE(:,i)=meanstd2(PmE',num2str(i),');']);
end
%
%
mean_beta=meanstd2(betaterm);
mean_salt=mean_eta./(h_mix*mean_beta(:,ones(1,12)));
%
save model_freshwater_fluxes eta1 eta2 eta3 eta4 eta5 eta6 eta7...
    eta8 eta9 eta10 eta11 eta12 lat lon




