%
% Time evolving Sverdrup problem for testing Altimetry data
%
% Author:  N.L Bindoff
% Date: 1 August 1996
% 
% Load the data for the wind fields.
% In this case it is Hellerman and Rosenstein
%
% Load winds 
load depths
mask=zeros(size(depth));
ii=find(depth>=0);
mask(ii)= NaN*ones(1,length(ii));
ii=find(depth<0);
mask(ii)= 0.0*ones(1,length(ii));
%
load hellerman.mat
jj=find(lat(:,1)<=62 & lat(:,1)>=-62)
%
% Calculate the Curl of wind field
%
[m,n]=size(decx);
curl1=0.1*curl_z(janx(jj,:),jany(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl2=0.1*curl_z(febx(jj,:),feby(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl3=0.1*curl_z(marx(jj,:),mary(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl4=0.1*curl_z(aprx(jj,:),apry(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl5=0.1*curl_z(mayx(jj,:),mayy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl6=0.1*curl_z(junx(jj,:),juny(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl7=0.1*curl_z(julx(jj,:),july(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl8=0.1*curl_z(augx(jj,:),augy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl9=0.1*curl_z(sepx(jj,:),sepy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl10=0.1*curl_z(octx(jj,:),octy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl11=0.1*curl_z(novx(jj,:),novy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
curl12=0.1*curl_z(decx(jj,:),decy(jj,:),lat(jj,ones(1,n)),lon(:,ones(m,1))');
%
% Calculate the wind field anomalies and mask the land values
%
av_curl=(curl1+curl2+curl3+curl4+curl5+curl5+curl6+...
    curl7+curl8+curl9+curl10+curl12)/12;
%av_curl= av_curl + mask(2:89,2:179); 
%
%curl1=curl1-av_curl;
%curl2=curl2-av_curl;
%curl3=curl3-av_curl;
%curl4=curl4-av_curl;
%curl5=curl5-av_curl;
%curl6=curl6-av_curl;
%curl7=curl7-av_curl;
%curl8=curl8-av_curl;
%curl9=curl9-av_curl;
%curl10=curl10-av_curl;
%curl11=curl11-av_curl;
%curl12=curl12-av_curl;
%
% curl1, curl2, curl3, ... are the wind stress curl field
% for january, february, march, ....
%
% The CURL grid is 
%
m=length(jj)
lat=lat(jj(2:m-1))
lon=lon(2:n-1)
degrad=pi/180;
%
% define density and equivalent depth and gravity
%
%
%c_1=g*H
%omega=7.292e-5
%f=(2*omega*sin(degrad*(lat(:,ones(1,n-2)))));
%beta=(2*omega*cos(degrad*(lat(:,ones(1,n-2)))))/(6371*1000);
%deg2m=2*111*1000*cos(degrad*(lat(:,ones(1,n-2))));
%k=2*pi/(90*111*1000)
%factor= -f.*deg2m./(rho*g*H*beta);
%
%
% Integrate the wind field using sverdrup relation 
%
r=6371000;              % radius of the earth at the equator (metres)
rot=7.292e-5;           % rotation rate of the earth
phi=phi*pi/180;         % convert latitude to radians
%
% initialise
%
nfactor=10
delt=1.0/nfactor*86400		% deltax = 1 day in seconds
tspd=1.0*nfactor
tspy=nfactor*360;		% time steps per year
delx=222*cos(phi)*1000  % deltat =  2 degree grid spacing in metres
%
%
%
% initialise variables
%
[m,n]=size(curl1)
psin=zeros(m,n);
psinm1=zeros(m,n);
psinp1=zeros(m,n);
%
% set mask so land values 0, and ocean values 1's
mask2=mask(jj(2):jj(length(jj)-1),2:179);
mask3=mask(jj(2):jj(length(jj)-1),2:179);           %has land mask
ii1=find(isnan(mask2));
ii2=find(finite(mask2));
mask2(ii1)=zeros(1,length(ii1));
mask2(ii2)=ones(1,length(ii2));
figure
colormap('jet')
pcolor(lon,lat,mask2)
xlabel('Longitude')
ylabel('Latitude')
shading flat
colorbar
%
% initialise delx, in metres
delx=111*1000*(lon(2)-lon(1))*ones(m,1).*cos(degrad*lat);
%
% initialise f
f=2*rot*sin(degrad*lat)        % coriolis parameter (per second)
factor=0.2e-4
f=f+factor*sign(f).*ones(m,1);
%
%
% initialise beta
beta=2*rot*cos(degrad*lat)/r;
% 
% initialise c  (3 m.s-1) except at equator
crtest=0.05*ones(length(lat),1).*cos(degrad*lat).^6
c=sqrt(crtest.*f.^2./beta)
%c=6*ones(m,1)-5.5*cos(degrad*lat).^32;
figure
plot(lat,c)
xlabel('Latitude')
ylabel('C speed')
%
% initialise dissipation
dissipation=5.0e-4;
%
%
%
%
% Check the stability criterion (Von Neumann Stability Analysis -
% cf Numerical Recipes pp 625-6)
%
lhs=c.^2./(f.^2).*beta*delt
figure
hold off
plot(lat,lhs,'w-')
hold on
plot(lat,delx,'w-.')
xlabel('Latitude')
ylabel('Stability Criterion')
%
if (lhs >=delx),
	string='GOT A PROBLEM WITH STABILITY - PAUSE!!'
	pause
end
%
%
cr=beta.*c.^2./f.^2
figure
plot(lat,cr)
xlabel('Latitude')
ylabel('Cr (m/s)')
%
%
j=1
k=0;
NN=12
sindex=0
curl=zeros(m,n);
years=6
%
%
string='STARTING'
%
for i=1:years*tspy,
%
% interpolate curl field for this time step
        day=fix(i/tspd);
        month = rem(day,360);
        month =fix((month/360)*NN)+1;
        frac_month = rem(day,360/NN)/(360/NN);
%	keyboard
        if month < NN,
	  string=['curl = curl',num2str(month),'+frac_month*(curl',num2str(month+1),'-curl',num2str(month),');'];
          eval(string)
	else
 	  string=['curl = curl',num2str(month),'+frac_month*(curl1-curl',num2str(month),');'];
          eval(string)
        end
%
%        keyboard
        [psinp1]=vorticity2(psinm1,psin,curl,mask2, ...
			delt,delx,f,c,beta,dissipation);
	psinm1=psin;
	psin=psinp1;
%
	n=n+1;
%
% save some matrices
%
        if rem(i,tspd*10)==0,
	  sindex=sindex+1
	  string=['psi',num2str(sindex),'=psinp1;']
	  eval(string)
	  day
	  month
	  frac_month
	end
end
%
figure
colormap('jet')
pcolor(lon,lat,psi182)
xlabel('Longitude')
ylabel('Latitude')
shading flat
colorbar
%
% Convert history files to data
%
%load workspace
%
save workspace2
